==> goods-center-biz-1.8.5-20170111.123239-1-sources.jar: cn/com/duiba/goods/center/biz/remoteservice/item/RemoteDuibaItemGoodsServiceImpl.java <==
package cn.com.duiba.goods.center.biz.remoteservice.item;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import cn.com.duiba.goods.center.api.remoteservice.dto.item.ItemDto;
import cn.com.duiba.goods.center.api.remoteservice.item.RemoteDuibaItemGoodsService;
import cn.com.duiba.goods.center.biz.entity.ItemEntity;
import cn.com.duiba.goods.center.biz.service.item.ItemService;
import cn.com.duiba.wolf.cache.CacheClient;
import cn.com.duiba.wolf.dubbo.DubboResult;
import cn.com.duiba.wolf.utils.BeanUtils;

/**
 * 
 * RemoteDuibaItemGoodsServiceImpl
 *
 */
@Service
public class RemoteDuibaItemGoodsServiceImpl implements RemoteDuibaItemGoodsService {

	private static final Logger LOGGER = LoggerFactory.getLogger(RemoteDuibaItemGoodsServiceImpl.class);

	@Autowired
	private ItemService itemService;

	@Autowired
	private CacheClient cacheClient;

	@Override
	public DubboResult<ItemDto> find(Long id) {
		try {
			ItemEntity entity = itemService.find(id);
			ItemDto dto = BeanUtils.copy(entity, ItemDto.class);
			return DubboResult.successResult(dto);
		} catch (Exception e) {
			LOGGER.error("find:" + id, e);
			return DubboResult.failResult(e.getMessage());
		}
	}

	@Override
	public DubboResult<List<ItemDto>> findByIds(List<Long> ids) {
		try {
			List<ItemEntity> entitys = itemService.findByIds(ids);
			List<ItemDto> dtos = BeanUtils.copyList(entitys, ItemDto.class);
			return DubboResult.successResult(dtos);
		} catch (Exception e) {
			LOGGER.error("findByIds:", e);
			return DubboResult.failResult(e.getMessage());
		}
	}

	@Override
	public DubboResult<Long> insert(ItemDto itemDto) {
		try {
			ItemEntity entity = BeanUtils.copy(itemDto, ItemEntity.class);
			Long id = itemService.insert(entity);
			return DubboResult.successResult(id);
		} catch (Exception e) {
			LOGGER.error("insert:", e);
			return DubboResult.failResult(e.getMessage());
		}
	}

	@Override
	public DubboResult<Boolean> update(ItemDto itemDto) {
		try {
			ItemEntity entity = BeanUtils.copy(itemDto, ItemEntity.class);
			Boolean ret = itemService.update(entity);
			return DubboResult.successResult(ret);
		} catch (Exception e) {
			LOGGER.error("update:", e);
			return DubboResult.failResult(e.getMessage());
		}
	}

	@Override
	public DubboResult<Boolean> delete(Long itemId) {
		try {
			Boolean ret = itemService.delete(itemId);
			return DubboResult.successResult(ret);
		} catch (Exception e) {
			LOGGER.error("delete:", e);
			return DubboResult.failResult(e.getMessage());
		}
	}

	@Override
	public DubboResult<Boolean> updateEnable(Long itemId, Boolean enable) {
		try {
			Boolean ret = itemService.updateEnable(itemId, enable);
			return DubboResult.successResult(ret);
		} catch (Exception e) {
			LOGGER.error("updateEnable:", e);
			return DubboResult.failResult(e.getMessage());
		}
	}

	@Override
	public DubboResult<Boolean> appendStock(Long itemId, Long number) {
		try {
			Boolean ret = itemService.appendStock(itemId, number);
			return DubboResult.successResult(ret);
		} catch (Exception e) {
			LOGGER.error("appendStock:", e);
			return DubboResult.failResult(e.getMessage());
		}
	}

	@Override
	public DubboResult<Boolean> deductStock(Long itemId, Long number) {
		try {
			Boolean ret = itemService.deductStock(itemId, number);
			return DubboResult.successResult(ret);
		} catch (Exception e) {
			LOGGER.error("deductStock:", e);
			return DubboResult.failResult(e.getMessage());
		}
	}

	@Override
	public DubboResult<List<ItemDto>> findAutoRecommend(Long appId) {
		try {
			List<ItemEntity> entitys = itemService.findAutoRecommend(appId);
			List<ItemDto> dtos = BeanUtils.copyList(entitys, ItemDto.class);
			return DubboResult.successResult(dtos);
		} catch (Exception e) {
			LOGGER.error("findAutoRecommend:appId=" + appId, e);
			return DubboResult.failResult(e.getMessage());
		}
	}

}

==> goods-center-biz-1.9.1-20170204.062920-1-sources.jar: cn/com/duiba/goods/center/biz/remoteservice/item/RemoteDuibaItemGoodsServiceImpl.java <==
package cn.com.duiba.goods.center.biz.remoteservice.item;

import java.util.List;
import java.util.Map;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import cn.com.duiba.goods.center.api.remoteservice.dto.item.ItemDto;
import cn.com.duiba.goods.center.api.remoteservice.dto.item.ItemKeyDto;
import cn.com.duiba.goods.center.api.remoteservice.item.RemoteDuibaItemGoodsService;
import cn.com.duiba.goods.center.biz.bo.item.ItemAutoRecommendBo;
import cn.com.duiba.goods.center.biz.entity.ItemEntity;
import cn.com.duiba.goods.center.biz.service.item.ItemService;
import cn.com.duiba.wolf.cache.CacheClient;
import cn.com.duiba.wolf.dubbo.DubboResult;
import cn.com.duiba.wolf.utils.BeanUtils;

/**
 * 
 * RemoteDuibaItemGoodsServiceImpl
 *
 */
@Service
public class RemoteDuibaItemGoodsServiceImpl implements RemoteDuibaItemGoodsService {

	private static final Logger LOGGER = LoggerFactory.getLogger(RemoteDuibaItemGoodsServiceImpl.class);

	@Autowired
	private ItemService itemService;
	
	@Autowired
	private ItemAutoRecommendBo itemAutoRecommendBo;

	@Autowired
	private CacheClient cacheClient;

	@Override
	public DubboResult<ItemDto> find(Long id) {
		try {
			ItemEntity entity = itemService.find(id);
			ItemDto dto = BeanUtils.copy(entity, ItemDto.class);
			return DubboResult.successResult(dto);
		} catch (Exception e) {
			LOGGER.error("find:" + id, e);
			return DubboResult.failResult(e.getMessage());
		}
	}

	@Override
	public DubboResult<List<ItemDto>> findByIds(List<Long> ids) {
		try {
			List<ItemEntity> entitys = itemService.findByIds(ids);
			List<ItemDto> dtos = BeanUtils.copyList(entitys, ItemDto.class);
			return DubboResult.successResult(dtos);
		} catch (Exception e) {
			LOGGER.error("findByIds:", e);
			return DubboResult.failResult(e.getMessage());
		}
	}

	@Override
	public DubboResult<Long> insert(ItemDto itemDto) {
		try {
			ItemEntity entity = BeanUtils.copy(itemDto, ItemEntity.class);
			Long id = itemService.insert(entity);
			return DubboResult.successResult(id);
		} catch (Exception e) {
			LOGGER.error("insert:", e);
			return DubboResult.failResult(e.getMessage());
		}
	}

	@Override
	public DubboResult<Boolean> update(ItemDto itemDto) {
		try {
			ItemEntity entity = BeanUtils.copy(itemDto, ItemEntity.class);
			Boolean ret = itemService.update(entity);
			return DubboResult.successResult(ret);
		} catch (Exception e) {
			LOGGER.error("update:", e);
			return DubboResult.failResult(e.getMessage());
		}
	}

	@Override
	public DubboResult<Boolean> delete(Long itemId) {
		try {
			Boolean ret = itemService.delete(itemId);
			return DubboResult.successResult(ret);
		} catch (Exception e) {
			LOGGER.error("delete:", e);
			return DubboResult.failResult(e.getMessage());
		}
	}

	@Override
	public DubboResult<Boolean> updateEnable(Long itemId, Boolean enable) {
		try {
			Boolean ret = itemService.updateEnable(itemId, enable);
			return DubboResult.successResult(ret);
		} catch (Exception e) {
			LOGGER.error("updateEnable:", e);
			return DubboResult.failResult(e.getMessage());
		}
	}

	@Override
	public DubboResult<Boolean> appendStock(Long itemId, Long number) {
		try {
			Boolean ret = itemService.appendStock(itemId, number);
			return DubboResult.successResult(ret);
		} catch (Exception e) {
			LOGGER.error("appendStock:", e);
			return DubboResult.failResult(e.getMessage());
		}
	}

	@Override
	public DubboResult<Boolean> deductStock(Long itemId, Long number) {
		try {
			Boolean ret = itemService.deductStock(itemId, number);
			return DubboResult.successResult(ret);
		} catch (Exception e) {
			LOGGER.error("deductStock:", e);
			return DubboResult.failResult(e.getMessage());
		}
	}

	@Override
	public DubboResult<List<ItemDto>> findAutoRecommend(Long appId) {
		try {
			List<ItemEntity> entitys = itemService.findAutoRecommend(appId);
			List<ItemDto> dtos = BeanUtils.copyList(entitys, ItemDto.class);
			return DubboResult.successResult(dtos);
		} catch (Exception e) {
			LOGGER.error("findAutoRecommend:appId=" + appId, e);
			return DubboResult.failResult(e.getMessage());
		}
	}

	@Override
	public DubboResult<List<ItemKeyDto>> findAutoRecommendItemKey(Long appId) {
		try {
			List<ItemKeyDto> dtos = itemAutoRecommendBo.findHomeAutoRecommend(appId, 20);
			return DubboResult.successResult(dtos);
		} catch (Exception e) {
			LOGGER.error("findAutoRecommendItemKey:appId=" + appId, e);
			return DubboResult.failResult(e.getMessage());
		}
	}

	@Override
	public DubboResult<List<ItemKeyDto>> findAutoRecommendItemKey(Long appId, Integer size, Map<String, Object> query) {
		try {
			List<ItemKeyDto> dtos = itemAutoRecommendBo.findAutoRecommend(appId, size, query);
			return DubboResult.successResult(dtos);
		} catch (Exception e) {
			LOGGER.error("findAutoRecommendItemKey:appId=" + appId, e);
			return DubboResult.failResult(e.getMessage());
		}

	}

}
